@@ -1,9 +1,8 @@
 from .utils import *
 from .masks import *
 from .multicorr import *
-from .ellipticalCoords import *
+from .elliptical_coords import *
 from .single_atom_scatter import *
 from .parameters import *
-from .aberrations import *
 from .tqdmnd import *
 
