@@ -152,17 +152,64 @@ def get_shift(ar1, ar2, corrPower=1):
     return xshift, yshift
 
 
-def get_shifted_ar(ar, xshift, yshift):
+def get_shifted_ar(
+    ar, 
+    xshift, 
+    yshift,
+    periodic=True,
+    bilinear=False,
+    ):
     """
-	Shifts array ar by the shift vector (xshift,yshift), using the Fourier shift theorem (i.e.
-	with sinc interpolation).
+	Shifts array ar by the shift vector (xshift,yshift), using the either 
+    the Fourier shift theorem (i.e. with sinc interpolation), or bilinear
+    resampling. Boundary conditions can be periodic or not.
+
+    Args:
+            ar (float): input array 
+            xshift (float): shift along axis 0 (x) in pixels
+            yshift (float): shift along axis 1 (y) in pixels
+            periodic (bool): flag for periodic boundary conditions
+            bilinear (bool): flag for bilinear image shifts
+
+        Returns:
+            (array) the shifted array              
     """
-    nx, ny = np.shape(ar)
-    qx, qy = make_Fourier_coords2D(nx, ny, 1)
-    nx, ny = float(nx), float(ny)
+
+    # Apply image shift
+    if bilinear is False:
+        nx, ny = np.shape(ar)
+        qx, qy = make_Fourier_coords2D(nx, ny, 1)
+        nx, ny = float(nx), float(ny)
+
+        w = np.exp(-(2j * np.pi) * ((yshift * qy) + (xshift * qx)))
+        shifted_ar = np.real(np.fft.ifft2((np.fft.fft2(ar)) * w))
+
+    else:
+        xF = (np.floor(xshift)).astype(int)
+        yF = (np.floor(yshift)).astype(int)
+        wx = xshift - xF
+        wy = yshift - yF
+            
+        shifted_ar = \
+            np.roll(ar,(xF  ,yF  ),axis=(0,1)) * ((1-wx)*(1-wy)) + \
+            np.roll(ar,(xF+1,yF  ),axis=(0,1)) * ((  wx)*(1-wy)) + \
+            np.roll(ar,(xF  ,yF+1),axis=(0,1)) * ((1-wx)*(  wy)) + \
+            np.roll(ar,(xF+1,yF+1),axis=(0,1)) * ((  wx)*(  wy))
+
+    if periodic is False:
+        # Rounded coordinates for boundaries
+        xR = (np.round(xshift)).astype(int)
+        yR = (np.round(yshift)).astype(int)
+
+        if xR > 0:
+            shifted_ar[0:xR,:] = 0
+        elif xR < 0:
+            shifted_ar[xR:,:] = 0    
+        if yR > 0:
+            shifted_ar[:,0:yR] = 0
+        elif yR < 0:
+            shifted_ar[:,yR:] = 0    
 
-    w = np.exp(-(2j * np.pi) * ((yshift * qy) + (xshift * qx)))
-    shifted_ar = np.real(np.fft.ifft2((np.fft.fft2(ar)) * w))
     return shifted_ar
 
 
@@ -217,12 +264,23 @@ def get_CoM(ar):
 def get_maximal_points(ar):
     """
     For 2D array ar, returns an array of bools of the same shape which is True for all entries with
-    values larger than all 8 of their nearest neighbors.
+    values larger than all 8 of their nearest neighbors.  Excludes all boundary pixels.
     """
-    return (ar > np.roll(ar, (-1, 0), axis=(0, 1))) & (ar > np.roll(ar, (1, 0), axis=(0, 1))) & \
-           (ar > np.roll(ar, (0, -1), axis=(0, 1))) & (ar > np.roll(ar, (0, 1), axis=(0, 1))) & \
-           (ar > np.roll(ar, (-1, -1), axis=(0, 1))) & (ar > np.roll(ar, (-1, 1), axis=(0, 1))) & \
-           (ar > np.roll(ar, (1, -1), axis=(0, 1))) & (ar > np.roll(ar, (1, 1), axis=(0, 1)))
+
+    # local max including periodic wrap-around
+    local_max = \
+        (ar > np.roll(ar, (-1, 0), axis=(0, 1))) & (ar > np.roll(ar, (1, 0), axis=(0, 1))) & \
+        (ar > np.roll(ar, (0, -1), axis=(0, 1))) & (ar > np.roll(ar, (0, 1), axis=(0, 1))) & \
+        (ar > np.roll(ar, (-1, -1), axis=(0, 1))) & (ar > np.roll(ar, (-1, 1), axis=(0, 1))) & \
+        (ar > np.roll(ar, (1, -1), axis=(0, 1))) & (ar > np.roll(ar, (1, 1), axis=(0, 1)))
+
+    # remove boundary max
+    local_max[0,:] = False
+    local_max[:,0] = False
+    local_max[-1,:] = False
+    local_max[:,-1] = False
+
+    return local_max
 
 
 def get_maxima_2D(ar,
@@ -232,7 +290,7 @@ def get_maxima_2D(ar,
                   minRelativeIntensity=0,
                   minAbsoluteIntensity=0,
                   relativeToPeak=0,
-                  maxNumPeaks=0,
+                  maxNumPeaks=1,
                   subpixel='poly',
                   ar_FT=None,
                   upsample_factor=16):
@@ -252,7 +310,7 @@ def get_maxima_2D(ar,
         minAbsoluteIntensity (float): the minimum acceptable correlation peak intensity,
             on an absolute scale
         relativeToPeak (int): 0=brightest maximum. 1=next brightest, etc.
-        maxNumPeaks (int): return only the first maxNumPeaks maxima
+        maxNumPeaks (int): return only the first maxNumPeaks maxima. Set to None to return all peaks.
         subpixel (str): Whether to use subpixel fitting, and which algorithm to use.
             Must be in ('none','poly','multicorr').
                 * 'none': performs no subpixel fitting
@@ -272,6 +330,10 @@ def get_maxima_2D(ar,
     """
     assert subpixel in [ 'none', 'poly', 'multicorr' ], "Unrecognized subpixel option {}, subpixel must be 'none', 'poly', or 'multicorr'".format(subpixel)
 
+
+    if maxNumPeaks is not None:
+        maxNumPeaks = np.asarray(maxNumPeaks, dtype='int')
+
     # Get maxima
     ar = gaussian_filter(ar, sigma)
     maxima_bool = get_maximal_points(ar)
@@ -298,6 +360,7 @@ def get_maxima_2D(ar,
     maxima['intensity'] = ar[maxima_x, maxima_y]
     maxima = np.sort(maxima, order='intensity')[::-1]
 
+
     if len(maxima) > 0:
         # Remove maxima which are too close
         if minSpacing > 0:
@@ -322,11 +385,11 @@ def get_maxima_2D(ar,
             maxima = np.delete(maxima, np.nonzero(deletemask)[0])
 
         # Remove maxima in excess of maxNumPeaks
-        if maxNumPeaks > 0:
-            assert isinstance(maxNumPeaks, (int, np.integer))
+        if maxNumPeaks is not None:
             if len(maxima) > maxNumPeaks:
                 maxima = maxima[:maxNumPeaks]
 
+
         # Subpixel fitting 
         # For all subpixel fitting, first fit 1D parabolas in x and y to 3 points (maximum, +/- 1 pixel)
         if subpixel != 'none':
@@ -440,6 +503,9 @@ def add_to_2D_array_from_floats(ar, x, y, I):
     """
     Adds the values I to array ar, distributing the value between the four pixels nearest
     (x,y) using linear interpolation.  Inputs (x,y,I) may be floats or arrays of floats.
+
+    Note that if the same [x,y] coordinate appears more than once in the input array,
+    only the *final* value of I at that coordinate will get added.
     """
     Nx, Ny = ar.shape
     x0, x1 = (np.floor(x)).astype(int), (np.ceil(x)).astype(int)
@@ -839,4 +905,4 @@ def fourier_resample(
     # Normalization
     array_resize = array_resize * scale_output
 
-    return array_resize
\ No newline at end of file
+    return array_resize
