@@ -1,8 +1,8 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.axes import Axes
-from .visualize import show,show_points
-from ..process.calibration import get_Qvector_from_Rvector,get_Rvector_from_Qvector
+from .show import show,show_points
+from ..process.calibration.rotation import get_Qvector_from_Rvector,get_Rvector_from_Qvector
 
 def show_selected_dp(datacube,image,rx,ry,figsize=(12,6),returnfig=False,
                      pointsize=50,pointcolor='r',scaling='log',**kwargs):
@@ -10,7 +10,7 @@ def show_selected_dp(datacube,image,rx,ry,figsize=(12,6),returnfig=False,
     """
     dp = datacube.data[rx,ry,:,:]
     fig,(ax1,ax2) = plt.subplots(1,2,figsize=figsize)
-    _,_=show_points(image,rx,ry,scale=pointsize,point_color=pointcolor,figax=(fig,ax1),returnfig=True)
+    _,_=show_points(image,rx,ry,scale=pointsize,pointcolor=pointcolor,figax=(fig,ax1),returnfig=True)
     _,_=show(dp,figax=(fig,ax2),scaling=scaling,returnfig=True)
     if not returnfig:
         plt.show()
@@ -103,8 +103,8 @@ def ax_addvector_QtoR(ax,vx,vy,vlength,x0,y0,QR_rotation,width=1,color='r'):
     vx,vy = vx*vlength,vy*vlength
     ax.arrow(y0,x0,vy,vx,color=color,width=width,length_includes_head=True)
 
-def show_RQ_vector(realspace_image, realspace_pdict,
-                   diffractionspace_image, diffractionspace_pdict,
+def show_RQ_vector(realspace_image, diffractionspace_image,
+                   realspace_pdict, diffractionspace_pdict,
                    vx,vy,vlength_R,vlength_Q,x0_R,y0_R,x0_Q,y0_Q,
                    QR_rotation,vector_space='R',
                    width_R=1,color_R='r',
@@ -154,8 +154,8 @@ def show_RQ_vector(realspace_image, realspace_pdict,
     else:
         return fig,(ax1,ax2)
 
-def show_RQ_vectors(realspace_image, realspace_pdict,
-                    diffractionspace_image, diffractionspace_pdict,
+def show_RQ_vectors(realspace_image, diffractionspace_image,
+                    realspace_pdict, diffractionspace_pdict,
                     vx,vy,vlength_R,vlength_Q,x0_R,y0_R,x0_Q,y0_Q,
                     QR_rotation,vector_space='R',
                     width_R=1,color_R='r',
@@ -305,7 +305,7 @@ def ax_addaxes_RtoQ(ax,vx,vy,vlength,x0,y0,QR_rotation,width=1,color='r',
     ax_addaxes(ax,vx,vy,vlength,x0,y0,width=width,color=color,labelaxes=labelaxes,
                labelsize=labelsize,labelcolor=labelcolor,righthandedcoords=True)
 
-def show_RQ_axes(realspace_image, diffractionspace_image,
+def show_RQ_axes(realspace_image,diffractionspace_image,
                  realspace_pdict, diffractionspace_pdict,
                  vx,vy,vlength_R,vlength_Q,x0_R,y0_R,x0_Q,y0_Q,
                  QR_rotation,vector_space='R',
